aboutsummaryrefslogtreecommitdiffstats
path: root/phpBB/styles
diff options
context:
space:
mode:
authorCallum Macrae <callum@macr.ae>2014-09-10 09:52:58 +0100
committerCallum Macrae <callum@macr.ae>2014-09-10 09:58:46 +0100
commitcb7e1540c64025071e1061d7708cb0c946a198f4 (patch)
treebb611c9d1e5290a8cf80acad4adec12a66c0fcc0 /phpBB/styles
parent9c87972385a1dce05ac622fcac42530d2885dfae (diff)
downloadforums-cb7e1540c64025071e1061d7708cb0c946a198f4.tar
forums-cb7e1540c64025071e1061d7708cb0c946a198f4.tar.gz
forums-cb7e1540c64025071e1061d7708cb0c946a198f4.tar.bz2
forums-cb7e1540c64025071e1061d7708cb0c946a198f4.tar.xz
forums-cb7e1540c64025071e1061d7708cb0c946a198f4.zip
[ticket/12982] Refactoring: Killed undescriptive variables
PHPBB3-12982
Diffstat (limited to 'phpBB/styles')
-rw-r--r--phpBB/styles/prosilver/template/ajax.js13
1 files changed, 6 insertions, 7 deletions
diff --git a/phpBB/styles/prosilver/template/ajax.js b/phpBB/styles/prosilver/template/ajax.js
index 123d5ce7f9..458951bf97 100644
--- a/phpBB/styles/prosilver/template/ajax.js
+++ b/phpBB/styles/prosilver/template/ajax.js
@@ -116,16 +116,16 @@ phpbb.addAjaxCallback('notification.mark_read', function(res) {
/**
* Mark notification popup rows as read.
*
* @param {jQuery} $el jQuery object(s) to mark read.
* @param {int} unreadCount The new unread notifications count.
*/
-phpbb.markNotifications = function($el, unreadCount) {
+phpbb.markNotifications = function($popup, unreadCount) {
// Remove the unread status.
- $el.removeClass('bg2');
- $el.find('a.mark_read').remove();
+ $popup.removeClass('bg2');
+ $popup.find('a.mark_read').remove();
// Update the notification link to the real URL.
- $el.each(function() {
+ $popup.each(function() {
var link = $(this).find('a');
link.attr('href', link.attr('data-real-url'));
});
@@ -164,8 +164,7 @@ phpbb.addAjaxCallback('post_visibility', function(res) {
$(this).remove();
});
- if (res.visible)
- {
+ if (res.visible) {
// Remove the "Deleted by" message from the post on restoring.
remove.parents('.post').find('.post_deleted_msg').css('pointer-events', 'none').fadeOut(function() {
$(this).remove();
@@ -116,16 +116,16 @@ phpbb.addAjaxCallback('notification.mark_read', function(res) {
* Mark notification popup rows as read.
*
- * @param {jQuery} $el jQuery object(s) to mark read.
+ * @param {jQuery} $popup jQuery object(s) to mark read.
* @param {int} unreadCount The new unread notifications count.
*/